==> kita-0.140.0.tar.gz: kita-0.140.0/kita/src/libkita/board.h <==
/***************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto                                  *
*   ikemo@users.sourceforge.jp                                            *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef KITABOARD_H
#define KITABOARD_H

#include <kurl.h>

#include <qptrlist.h>
#include <qxml.h>
#include <qdict.h>

#include "thread.h"

/**
@author Hideki Ikemoto
*/

namespace Kita
{
    class Thread;

    class Board
    {
        QString m_boardURL;
        QString m_boardName;
        static QDict<Board>* m_boardDict;
        Board( const QString& boardURL, const QString boardName = QString::null );
        static Board* getByURL( const QString& boardURL );
    protected:
        Board();
    public:
        ~Board();
        const QString& url() const;
        const QString& name() const;
        const QString id() const;

        static int type( const QString& boardURL );
        
        static void setName( const QString& boardURL, const QString& boardName );
        static const QString& getName( const QString& boardURL );
        
        static const QPtrList<Thread> getThreadList( const QString& boardURL );
        static void replace( const QString& fromURL, const QString& toURL );
    };

    class NullBoard : public Board
    {
    public:
        NullBoard();
        ~NullBoard();
    };
}

#endif

==> kita-0.150.0.tar.gz: kita-0.150.0/kita/src/libkita/board.h <==
/***************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto                                  *
*   ikemo@users.sourceforge.jp                                            *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef KITABOARD_H
#define KITABOARD_H

#include <kurl.h>

#include <qptrlist.h>
#include <qxml.h>
#include <qdict.h>

#include "thread.h"

/**
@author Hideki Ikemoto
*/

namespace Kita
{
    class Thread;

    class Board
    {
        QString m_boardURL;
        QString m_boardName;
        static QDict<Board>* m_boardDict;
        Board( const QString& boardURL, const QString boardName = QString::null );
        static Board* getByURL( const QString& boardURL );
    protected:
        Board();
    public:
        ~Board();
        const QString& url() const;
        const QString& name() const;
        const QString id() const;
        static const QString getID( const QString& boardURL );
        
        static void setName( const QString& boardURL, const QString& boardName );
        static const QString& getName( const QString& boardURL );
        
        static const QPtrList<Thread> getThreadList( const QString& boardURL );
        static void replace( const QString& fromURL, const QString& toURL );
    };

    class NullBoard : public Board
    {
    public:
        NullBoard();
        ~NullBoard();
    };
}

#endif
